if (FALSE) {
## Request the list of all series from the BPM6 dataset
w_series_list("BPM6")
## Request the list of all series from the CPP dataset, with English metadata
w_series_list("CPP", language = "en")
## Your client ID can be entered as a parameter as follows or saved
## in a global variable named "webstat_client_ID" in order to reuse it.
w_series_list("CPP", client_ID = "1234abcd-12ab-12ab-12ab-123456abcdef")
}
Run the code above in your browser using DataLab